@@ -103,6 +103,10 @@ def create_manifest(source, categories, author, helpurl):
     # https://stackoverflow.com/questions/33892793/how-to-supply-multiple-options-with-array-validation
 
     filepath = click.format_filename(source)
+    appjson = get_file_data(filepath)
+    appjsondic = json.loads(appjson)
+    if (appjsondic.get('type', '') not in ('Folder', 'FolderSyncDefinition')) or ('children' not in appjsondic):
+        return cli_logger.error("Please export app folder instead of exporting single dashboard. Refer: https://help.sumologic.com/01Start-Here/Library/Export-and-Import-Content-in-the-Library#export-content-in-the-library for more details")
     am = AppManifest(filepath, categories, author, helpurl)
     manifestfile = filepath.replace(".json", ".manifest.json")
     manifest_exists = os.path.isfile(manifestfile)
@@ -392,4 +396,4 @@ class AppManifest(WholePrefixParameterSubstitutionMixin):
         for param in ["categories", "author", "help_url"]:
             new_val = getattr(self, param, None)
             if new_val:
-                self.appManifestDict[manifest_key_mapping.get(param, param)] = new_val
+                self.appManifestDict[manifest_key_mapping.get(param, param)] = new_val
\ No newline at end of file
