@@ -38,7 +38,7 @@ class TestApp(unittest.TestCase):
         self.HELP_HOME_URL = "https://help.sumologic.com/"
         self.S3_URL_PREFIX = "https://s3.amazonaws.com/"
         self.ICON_URL_PREFIX = ("https://app_icons.s3.amazonaws.com", self.S3_URL_PREFIX, "https://sumologic-partner-appsdata.s3.amazonaws.com")
-        self.SCREENSHOT_URL_PREFIX = ("https://sumologic-app-data.s3.amazonaws.com", self.S3_URL_PREFIX, "https://sumologic-partner-appsdata.s3.amazonaws.com")
+        self.SCREENSHOT_URL_PREFIX = ("https://sumologic-app-data.s3.amazonaws.com", self.S3_URL_PREFIX, "https://sumologic-partner-appsdata.s3.amazonaws.com","https://sumologic-app-data-v2.s3.amazonaws.com")
         self.HARDCODED_PARAM_APPS = ("InternalVolume", "Audit", "Artifactory", "Enterprise_Audit_Collector_Data_Forwarding", "Enterprise_Audit_Content_Management", "Enterprise_Audit_Security_Management", "Enterprise_Audit_User_role_Management")
         self.manifestfile = manifestfile
         self.appfile = appfile
@@ -78,7 +78,7 @@ class TestApp(unittest.TestCase):
             if self.is_mew_board(dash):
                 panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") else dash.get("panels", [])
                 for panel in panels:
-                    if panel.get("panelType") in ("TextPanel", "EventsOfInterestScatterPanel") or panel.get("Type") == "TextPanel":
+                    if panel.get("panelType") in ("TextPanel", "EventsOfInterestScatterPanel", "ServiceMapPanel") or panel.get("Type") == "TextPanel":
                         continue
                     for query in panel["queries"]:
                         panel_name = panel.get("title")
@@ -194,10 +194,24 @@ class TestApp(unittest.TestCase):
             if msg:
                 self.add_warning("HelpURL: %s %s" % (url, msg))
 
+    def test_has_collectiondoc(self):
+        helpdocidelelement = self.manifestjson.get("helpDocIdMap","")
+        if helpdocidelelement:
+            helpdocid = helpdocidelelement.get("en","")
+            docurl = "https://help.sumologic.com/@go/page/" + str(helpdocid)
+            resp = self._is_valid_url(docurl, "DocURL")
+            if hasattr(resp, "status_code"):
+                if resp.status_code != 200:
+                    msg = "Throwing %d status_code Reason: %s" % (resp.status_code, resp.reason)
+                    self.add_warning("collectionDocUrl: %s %s" % (docurl, msg))
+        else:
+            self.add_warning("This app : " + self.appname + " doesn't contain collectionDocUrl.")
+
+
     def test_has_category(self):
         catg = self.manifestjson.get("categories", [])
         self.assertTrue(len(catg) > 0, "No App category found")
-        self.assertTrue(len(catg) <= 3, "Maximum 3 App categories allowed")
+        self.assertTrue(len(catg) <= 4, "Maximum 4 App categories allowed")
 
     def test_has_valid_icon(self):
         url = self.manifestjson.get("iconURL", "")
@@ -449,6 +463,10 @@ class TestApp(unittest.TestCase):
         searches = copy.deepcopy(searches)
         searches = sorted(searches, key=lambda x: x.get("name"))
         return searches
+    
+    @abstractmethod
+    def test_has_valid_parseMode(self):
+        raise NotImplementedError
 
 
 class TestClassicDashboards(TestApp):
@@ -499,7 +517,7 @@ class TestClassicDashboards(TestApp):
 
         for dash in self.dashboards:
             if self.is_mew_board(dash):
-                self.assertTrue(self.matchanyterms(self.datetime_terms, json.dumps(dash["timeRange"])),
+                self.assertTrue(self.matchanyterms(self.datetime_terms, json.dumps(dash.get("timeRange"))),
                                 "Dashboard: %s does not use relative time" % dash.get("name"))
                 panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") else dash.get("panels", [])
                 for panel in panels:
@@ -522,19 +540,62 @@ class TestClassicDashboards(TestApp):
             if "schedules" in search:
                 self.add_warning("SavedSearch %s is scheduled with type %s" % (search['name'], search["schedules"]['notification']['type']))
 
+    def test_has_valid_parseMode(self):
+        for dash in self.dashboards:
+            panels = dash["rootPanel"]["panels"] if dash.get("rootPanel") is not None else dash.get("panels")
+            for panel in panels:
+                autoParsingInfo = None
+                if panel.get("autoParsingInfo") is not None :
+                    autoParsingInfo = panel.get("autoParsingInfo")
+                elif panel.get("autoParsingData") is not None:
+                    autoParsingInfo = panel.get("autoParsingData")
+                elif autoParsingInfo is not None : 
+                    autoParsingMode = autoParsingInfo.get("mode").lower()
+                    #intelligent and auto mode shouldn't be there.
+                    if autoParsingMode not in ("performance","manual"):
+                        self.add_warning("Parse mode found in panel, '" + panel.get("title") + "' :" + autoParsingMode)
+                else :
+                    if panel.get("name"):
+                        self.add_warning("Parse mode not found in panel: " + panel.get("name"))
+        for search in self.searches:
+            if search.get("parsingMode") is not None:
+                self.assertTrue(search["parsingMode"].lower() in ("performance","manual"), "App deployemnet will fail as incorrect parse mode found in search: " + search.get("name"))
+            else:
+                self.add_warning("Parse mode not found in search: " + search.get("name"))
+        
 
 class TestClassicDashboardsV2(TestApp):
 
+    def test_has_valid_parseMode(self):
+        for dash in self.dashboards:
+            panels = dash.get("panels")
+            for panel in panels:
+                queries = panel.get("queries")
+                if queries is not None:
+                    for query in queries:
+                        if query.get("parseMode") is not None:
+                            parseMode = query.get("parseMode").lower()
+                            if parseMode:
+                                if parseMode not in ("performance","manual"):
+                                    self.add_warning("Parse mode found in panel, '" + panel.get("title") + "' :" + parseMode)
+                        else:
+                            self.add_warning("Parse mode not found in panel: " + panel.get("title"))
+        for search in self.searches:
+            if search.get("search").get("parsingMode") is not None:
+                self.assertTrue(search["search"]["parsingMode"].lower() in ("performance","manual"), "App deployemnet will fail as incorrect parse mode found in search: " + search.get("name"))
+            else:
+                self.add_warning("Parse mode not found in search: " + search.get("name"))
+
     @classmethod
     def remove_text_panels(self, dashboards):
         for dash in dashboards:
             if self.is_mew_board(dash):
                 if dash.get("rootPanel"):
                     dash["rootPanel"]["panels"] = [panel for panel in dash["rootPanel"]["panels"] if
-                                                   not (panel["panelType"] in ("TextPanel", "EventsOfInterestScatterPanel"))]
+                                                   not (panel["panelType"] in ("TextPanel", "EventsOfInterestScatterPanel", "ServiceMapPanel"))]
 
                 else:
-                    dash["panels"] = [panel for panel in dash["panels"] if not (panel["panelType"] in ("TextPanel", "EventsOfInterestScatterPanel"))]
+                    dash["panels"] = [panel for panel in dash["panels"] if not (panel["panelType"] in ("TextPanel", "EventsOfInterestScatterPanel", "ServiceMapPanel"))]
 
 
             else:
@@ -600,13 +661,15 @@ class TestClassicDashboardsV2(TestApp):
         metric_variable_queries = []
         for dash in dashboards:
             if self.is_mew_board(dash):
-                for variable in dash.get("variables"):
-                    var_name = variable.get("name")
-                    definition = variable.get("sourceDefinition", {})
-                    if definition.get("variableSourceType") == "LogQueryVariableSourceDefinition":
-                        log_variable_queries.append((definition.get("query"), var_name, dash.get("name")))
-                    elif definition.get("variableSourceType") == "MetadataVariableSourceDefinition":
-                        metric_variable_queries.append((definition.get("filter"), var_name, dash.get("name")))
+                variables = dash.get("variables")
+                if variables:
+                    for variable in variables:
+                        var_name = variable.get("name")
+                        definition = variable.get("sourceDefinition", {})
+                        if definition.get("variableSourceType") == "LogQueryVariableSourceDefinition":
+                            log_variable_queries.append((definition.get("query"), var_name, dash.get("name")))
+                        elif definition.get("variableSourceType") == "MetadataVariableSourceDefinition":
+                            metric_variable_queries.append((definition.get("filter"), var_name, dash.get("name")))
 
         return log_variable_queries, metric_variable_queries
 
